@@ -173,9 +173,9 @@ class DiscreteVAE(nn.Module):
         logits = rearrange(logits, 'b n h w -> b (h w) n')
         qy = F.softmax(logits, dim = -1)
 
-        log_qy = torch.log(qy + 1e-20)
+        log_qy = torch.log(qy + 1e-10)
         log_uniform = torch.log(torch.tensor([1. / num_tokens], device = device))
-        kl_div = F.kl_div(log_uniform, log_qy, None, None, 'sum', log_target = True)
+        kl_div = F.kl_div(log_uniform, log_qy, None, None, 'batchmean', log_target = True)
 
         return recon_loss + (kl_div * kl_div_loss_weight)
 
